use strict;
use warnings;
package Task::BeLike::LOGIE;
BEGIN {
  $Task::BeLike::LOGIE::AUTHORITY = 'cpan:LOGIE';
}
{
  $Task::BeLike::LOGIE::VERSION = '0.02';
}

# ABSTRACT: Everyone wants to be like me!

__END__

=pod

=head1 NAME

Task::BeLike::LOGIE - Everyone wants to be like me!

=head1 VERSION

version 0.02

=head1 TASK CONTENTS

=head2 CPAN modules I tend to like

=head3 L<App::Ack>

=head3 L<DBIx::Class>

=head3 L<DateTime>

=head3 L<Dist::Zilla>

=head3 L<Moo>

=head3 L<Moose>

=head3 L<Plack>

=head3 L<Test::Most>

=head3 L<Try::Tiny>

=head3 L<namespace::autoclean>

=head1 AUTHOR

Logan Bell <loganbell@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Logan Bell.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
